=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-08-24 19:15:03 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-08-24 19:17:28 +0000
@@ -111,6 +111,23 @@
         self.assertListRaises(NoSuchFile, t.get_multi, ['a', 'b', 'c'])
         self.assertListRaises(NoSuchFile, t.get_multi, iter(['a', 'b', 'c']))
 
+    def test_get_bytes(self):
+        t = self.get_transport()
+
+        files = ['a', 'b', 'e', 'g']
+        contents = ['contents of a\n',
+                    'contents of b\n',
+                    'contents of e\n',
+                    'contents of g\n',
+                    ]
+        self.build_tree(files, transport=t, line_endings='binary')
+        self.check_transport_contents('contents of a\n', t, 'a')
+
+        for content, fname in zip(contents, files):
+            self.assertEqual(content, t.get_bytes(fname))
+
+        self.assertRaises(NoSuchFile, t.get_bytes, 'c')
+
     def test_put(self):
         t = self.get_transport()
 

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-08-24 19:15:03 +0000
+++ bzrlib/transport/__init__.py	2006-08-24 19:17:28 +0000
@@ -374,6 +374,13 @@
         """
         raise NotImplementedError(self.get)
 
+    def get_bytes(self, relpath):
+        """Get a raw string of the bytes for a file at the given location.
+
+        :param relpath: The relative path to the file
+        """
+        return self.get(relpath).read()
+
     def readv(self, relpath, offsets):
         """Get parts of the file at the given relative path.
 

